@@ -119,13 +119,14 @@ class DPAddon(dico_command.Addon, name="dp"):
 
     @dp.subcommand("addon")
     async def dp_addon(self, ctx: dico_command.Context, option: str = None, addon: str = "dp"):
-        print("it is", addon)
         if not option:
             return await ctx.reply(get_addons_info(self.bot))
         if option not in ["load", "unload", "reload"]:
             return await ctx.reply(f"Invalid option `{option}`. Must be one of `load`, `unload`, `reload`.")
         try:
             resolved = resolve_route(addon) if addon != "dp" else ["dp"]
+            if not resolved:
+                return await ctx.reply("No addons to reload found.")
         except ValueError as ex:
             return await ctx.reply(str(ex))
         action = {"load": self.bot.load_module, "unload": self.bot.unload_module, "reload": self.bot.reload_module}[option]
@@ -141,9 +142,9 @@ class DPAddon(dico_command.Addon, name="dp"):
 
     @dp.subcommand("py")
     async def dp_py(self, ctx: dico_command.Context, *, src: str):
-        ev = PYEval(ctx, self.bot, src)
         delete_button = dico.Button(style=dico.ButtonStyles.DANGER, emoji="🗑️", custom_id="trash")
         try:
+            ev = PYEval(ctx, self.bot, src)
             resp = await ev.evaluate()
             str_resp = [f"Result {i}:\n{x}" for i, x in enumerate(resp, start=1)] if len(resp) > 1 else [*map(str, resp)]
             pages = []
